@@ -32,11 +32,11 @@
 #include "dialogmsg.h"
 #include "tablewidget.h"
 
-favorites::favorites( QWidget * parent ) : QDialog( parent ),m_ui( new Ui::favorites )
+favorites::favorites( QWidget * parent ) : QDialog( parent ),
+	m_ui( new Ui::favorites )
 {
 	m_ui->setupUi( this ) ;
 
-	this->setWindowFlags( Qt::Window | Qt::Dialog ) ;
 	this->setFont( parent->font() ) ;
 
 	connect( m_ui->pbConfigFilePath,SIGNAL( clicked() ),this,SLOT( configPath() ) ) ;
@@ -66,6 +66,7 @@ favorites::favorites( QWidget * parent ) : QDialog( parent ),m_ui( new Ui::favor
 	table->setColumnWidth( 2,100 ) ;
 	table->setColumnWidth( 3,140 ) ;
 	table->setColumnWidth( 4,115 ) ;
+	table->setColumnWidth( 5,115 ) ;
 
 	this->addAction( [ this ](){
 
@@ -80,9 +81,47 @@ favorites::favorites( QWidget * parent ) : QDialog( parent ),m_ui( new Ui::favor
 
 	this->installEventFilter( this ) ;
 
+	utility::setParent( parent,&m_parentWidget,this ) ;
+
+	utility::setWindowOptions( this ) ;
+
+	this->checkFavoritesConsistency() ;
+
 	this->ShowUI() ;
 }
 
+void favorites::checkFavoritesConsistency()
+{
+	int s = m_ui->tableWidget->columnCount() - utility::favoritesEntrySize() ;
+
+	if( s == 0 ){
+
+		/*
+		 * It is ok,the size of the table is the same as what is in favorites
+		 */
+	}else if( s > 0 ){
+
+		/*
+		 * We will get here when a column was added in the table and we need to update
+		 * favorites entries to accomodate it.
+		 */
+
+		auto e = utility::readFavorites() ;
+
+		utility::clearFavorites() ;
+
+		for( const auto& it : e ){
+
+			utility::addToFavorite( it.configStringList() ) ;
+		}
+	}else{
+		/*
+		 * We will get here when a column was removed from the table and we need to update
+		 * favorites entries to accomodate it.
+		 */
+	}
+}
+
 bool favorites::eventFilter( QObject * watched,QEvent * event )
 {
 	return utility::eventFilter( this,watched,event,[ this ](){ this->HideUI() ; } ) ;
@@ -136,6 +175,8 @@ void favorites::ShowUI()
 	m_ui->tableWidget->setFocus() ;
 
 	this->show() ;
+	this->raise() ;
+	this->activateWindow() ;
 }
 
 void favorites::HideUI()
@@ -252,10 +293,11 @@ void favorites::cancel()
 
 void favorites::add()
 {
-	DialogMsg msg( this ) ;
+	DialogMsg msg( m_parentWidget,this ) ;
 
 	auto dev = m_ui->lineEditEncryptedFolderPath->text() ;
 	auto path = m_ui->lineEditMountPath->text() ;
+	auto mOpts = m_ui->lineEditMountOptions->text() ;
 
 	if( dev.isEmpty() ){
 
@@ -265,6 +307,13 @@ void favorites::add()
 
 		return msg.ShowUIOK( tr( "ERROR!" ),tr( "Mount Point Path Field Is Empty" ) ) ;
 	}
+	if( !mOpts.isEmpty() ){
+
+		if( mOpts.startsWith( "-" ) || mOpts.contains( ",-" ) ){
+
+			return msg.ShowUIOK( tr( "ERROR!" ),tr( "Mount Options Can Not Contain \"-\"" ) ) ;
+		}
+	}
 
 	m_ui->tableWidget->setEnabled( false ) ;
 
@@ -292,7 +341,8 @@ void favorites::add()
 			  path,
 			  autoMount,
 			  _option( m_ui->lineEditConfigFilePath->text() ),
-			  _option( m_ui->lineEditIdleTimeOut->text() ) } ;
+			  _option( m_ui->lineEditIdleTimeOut->text() ),
+			  _option( mOpts ) } ;
 
 	this->addEntries( e ) ;
 
